############################
Odin integration with Django
############################

Includes mapping of Django Models to Odin resources, and RESTful API implementation for Django using Odin resources.

.. image:: https://pypip.in/license/baldr/badge.png
    :target: https://pypi.python.org/pypi/baldr/
    :alt: License

.. image:: https://pypip.in/v/baldr/badge.png
    :target: https://pypi.python.org/pypi/baldr/

.. image:: https://travis-ci.org/python-odin/baldr.png?branch=master
    :target: https://travis-ci.org/python-odin/baldr
    :alt: Travis CI Status

.. image:: https://coveralls.io/repos/python-odin/baldr/badge.png?branch=master
    :target: https://coveralls.io/github/python-odin/baldr?branch=master
    :alt: Coveralls

.. image:: https://requires.io/github/timsavage/baldr/requirements.png?branch=master
    :target: https://requires.io/github/timsavage/baldr/requirements/?branch=master
    :alt: Requirements Status


Quick links
*********** 

* `Documentation <https://odin.readthedocs.org/en/development/integration/django>`_
* `Project home <https://github.com/python-odin/baldr>`_
* `Issue tracker <https://github.com/python-odin/baldr/issues>`_


Requires
********

* six
* odin >= 1.0+
* django >= 1.8+
